@@ -31,43 +31,41 @@ class Denom:
 
     @classmethod
     def load_market(cls, network, market_id):
-        config = None
         if network == 'devnet':
             config = devnet_config
-        if network == 'testnet':
+        elif network == 'testnet':
             config = testnet_config
-        if network == 'mainnet':
+        else:
             config =mainnet_config
 
         return cls(
-            description=config._sections[market_id]['description'],
-            base=int(config._sections[market_id]['base']),
-            quote=int(config._sections[market_id]['quote']),
-            min_price_tick_size=config._sections[market_id]['min_price_tick_size'],
-            min_quantity_tick_size=config._sections[market_id]['min_quantity_tick_size'],
+            description=config[market_id]['description'],
+            base=int(config[market_id]['base']),
+            quote=int(config[market_id]['quote']),
+            min_price_tick_size=float(config[market_id]['min_price_tick_size']),
+            min_quantity_tick_size=float(config[market_id]['min_quantity_tick_size']),
         )
 
     @classmethod
     def load_peggy_denom(cls, network, symbol):
-        config = None
         if network == 'devnet':
             config = devnet_config
-        if network == 'testnet':
+        elif network == 'testnet':
             config = testnet_config
-        if network == 'mainnet':
+        else:
             config = mainnet_config
-        return config._sections[symbol]['peggy_denom'], int(config._sections[symbol]['decimals'])
+        return config[symbol]['peggy_denom'], int(config[symbol]['decimals'])
 
 
 class Network:
     def __init__(
         self,
-        lcd_endpoint: str = None,
-        grpc_endpoint: str = None,
-        grpc_exchange_endpoint: str = None,
-        chain_id: str = None,
-        fee_denom: str = None,
-        env: str = None
+        lcd_endpoint: str ,
+        grpc_endpoint: str ,
+        grpc_exchange_endpoint: str ,
+        chain_id: str ,
+        fee_denom: str ,
+        env: str 
     ):
         self.lcd_endpoint = lcd_endpoint
         self.grpc_endpoint = grpc_endpoint
@@ -88,26 +86,35 @@ class Network:
         )
 
     @classmethod
-    def testnet(cls, sentry='primary'):
-        s = 'sentry0' if sentry == 'primary' else 'sentry1'
+    def testnet(cls, node='sentry1'):
+        nodes = ['sentry0', 'sentry1']
+        if node not in nodes:
+            raise ValueError("Must be one of {}".format(nodes))
 
         return cls(
             lcd_endpoint='https://testnet.lcd.injective.dev',
-            grpc_endpoint=f"{s}.injective.dev:9900",
-            grpc_exchange_endpoint=f"{s}.injective.dev:9910",
+            grpc_endpoint=f"{node}.injective.dev:9900",
+            grpc_exchange_endpoint=f"{node}.injective.dev:9910",
             chain_id='injective-888',
             fee_denom='inj',
             env='testnet'
         )
 
     @classmethod
-    def mainnet(cls, location='tokyo'):
-        s = 'sentry1' if location == 'tokyo' else 'sentry0'
+    def mainnet(cls, node='sentry2'):
+        nodes = [
+            'sentry0',  # us, prod
+            'sentry1',  # us, prod
+            'sentry2',  # us, staging
+            'sentry3',  # tokyo, prod
+        ]
+        if node not in nodes:
+            raise ValueError("Must be one of {}".format(nodes))
 
         return cls(
             lcd_endpoint='https://lcd.injective.network',
-            grpc_endpoint=f"{s}.injective.network:9900",
-            grpc_exchange_endpoint=f"{s}.injective.network:9910",
+            grpc_endpoint=f"{node}.injective.network:9900",
+            grpc_exchange_endpoint=f"{node}.injective.network:9910",
             chain_id='injective-1',
             fee_denom='inj',
             env='mainnet'
